@@ -29,10 +29,13 @@ int isatty(int);  /* returns 1 if stdin is a tty
                    if "Undefined symbol" this can be deleted along with call in main() */
 #endif
 
+#ifdef __APPLE__
+#include "fmemopen.h"
+#include "open_memstream.h"
+#endif
+
 /* duplicated in qconvex.htm */
 char hidden_options[]=" d v H Qbb Qf Qg Qm Qr Qu Qv Qx Qz TR E V Fp Gt Q0 Q1 Q2 Q3 Q4 Q5 Q6 Q7 Q8 Q9 ";
-char * tmp_in_prefix = "pyhull.in.";
-char * tmp_out_prefix = "pyhull.out.";
 
 static PyObject* qconvex(PyObject *self, PyObject *args) {
 
@@ -58,18 +61,17 @@ static PyObject* qconvex(PyObject *self, PyObject *args) {
     data = arg2;
   }
 
-  char *tmp_input_file = tempnam(NULL, tmp_in_prefix);
-  char *tmp_output_file = tempnam(NULL, tmp_out_prefix);
+  char *bp;
+  size_t size;
 
   /* Because qhull uses stdin and stdout streams for io, we need to create
-  FILE* stream to simulate these io streams. Suggestions on a better
-  cross-platform way to implement a string stream equivalent are welcome.*/
-  FILE *fin = fopen(tmp_input_file, "w+");
-  FILE *fout = fopen(tmp_output_file, "w+");
+  FILE* stream to simulate these io streams.*/
+  FILE* fin = fmemopen(data, strlen(data), "r");
+  FILE* fout = open_memstream(&bp, &size);
+
   PyObject* pydata;
   if ((fin != NULL) && (fout != NULL))
   {
-     fputs(data, fin);
      fseek(fin, 0, SEEK_SET);
      /* Now do the usual qhull code (modified from qconvex.c). */
      qh_init_A(fin, fout, stderr, argc, argv);
@@ -101,35 +103,14 @@ static PyObject* qconvex(PyObject *self, PyObject *args) {
            fprintf(stderr, "qhull internal warning (main): did not free %d bytes of long memory(%d pieces)\n",
            totlong, curlong);
      #endif
-
-     /* We need to know the number of lines in the file to allocate the PyList
-     object */
-
-     fseek(fout, 0, SEEK_SET);
-     int count = 0;
-     int MAX_BUF_SIZE = 300;
-     char buffer[MAX_BUF_SIZE];
-     while(fgets(buffer, MAX_BUF_SIZE, fout)){
-       count++;
-     }
-     fseek(fout, 0, SEEK_SET);
-     int i = 0;
-
-     pydata = PyList_New(count);
-     while(fgets(buffer,MAX_BUF_SIZE, fout)){
-        PyList_SetItem(pydata, i, PyString_FromString(buffer));
-        i++;
-     }
+     fclose(fin);
+     fclose(fout);
+     return Py_BuildValue("s", bp);
   }
   else
   {
      return NULL;
   }
-  fclose(fin);
-  fclose(fout);
-  remove(tmp_input_file);
-  remove(tmp_output_file);
-  return pydata;
 }
 
 static PyObject* qdelaunay(PyObject *self, PyObject *args) {
@@ -155,18 +136,18 @@ static PyObject* qdelaunay(PyObject *self, PyObject *args) {
       data = arg2;
     }
 
-  char *tmp_input_file = tempnam(NULL, tmp_in_prefix);
-  char *tmp_output_file = tempnam(NULL, tmp_out_prefix);
+
+  char *bp;
+  size_t size;
 
   /* Because qhull uses stdin and stdout streams for io, we need to create
-  FILE* stream to simulate these io streams. Suggestions on a better
-  cross-platform way to implement a string stream equivalent are welcome.*/
-  FILE *fin = fopen(tmp_input_file, "w+");
-  FILE *fout = fopen(tmp_output_file, "w+");
+  FILE* stream to simulate these io streams.*/
+  FILE* fin = fmemopen(data, strlen(data), "r");
+  FILE* fout = open_memstream(&bp, &size);
+
   PyObject* pydata;
   if ((fin != NULL) && (fout != NULL))
   {
-     fputs(data, fin);
      fseek(fin, 0, SEEK_SET);
      /* Now do the usual qhull code (modified from qconvex.c). */
      qh_init_A(fin, fout, stderr, argc, argv);  /* sets qh qhull_command */
@@ -202,34 +183,14 @@ static PyObject* qdelaunay(PyObject *self, PyObject *args) {
             totlong, curlong);
      #endif
 
-     /* We need to know the number of lines in the file to allocate the PyList
-     object */
-
-     fseek(fout, 0, SEEK_SET);
-     int count = 0;
-     int MAX_BUF_SIZE = 300;
-     char buffer[MAX_BUF_SIZE];
-     while(fgets(buffer, MAX_BUF_SIZE, fout)){
-       count++;
-     }
-     fseek(fout, 0, SEEK_SET);
-     int i = 0;
-
-     pydata = PyList_New(count);
-     while(fgets(buffer,MAX_BUF_SIZE, fout)){
-        PyList_SetItem(pydata, i, PyString_FromString(buffer));
-        i++;
-     }
+     fclose(fin);
+     fclose(fout);
+     return Py_BuildValue("s", bp);
   }
   else
   {
      return NULL;
   }
-  fclose(fin);
-  fclose(fout);
-  remove(tmp_input_file);
-  remove(tmp_output_file);
-  return pydata;
 }
 
 
@@ -256,18 +217,17 @@ static PyObject* qvoronoi(PyObject *self, PyObject *args) {
       data = arg2;
     }
 
-  char *tmp_input_file = tempnam(NULL, tmp_in_prefix);
-  char *tmp_output_file = tempnam(NULL, tmp_out_prefix);
+  char *bp;
+  size_t size;
 
   /* Because qhull uses stdin and stdout streams for io, we need to create
-  FILE* stream to simulate these io streams. Suggestions on a better
-  cross-platform way to implement a string stream equivalent are welcome.*/
-  FILE *fin = fopen(tmp_input_file, "w+");
-  FILE *fout = fopen(tmp_output_file, "w+");
+  FILE* stream to simulate these io streams.*/
+  FILE* fin = fmemopen(data, strlen(data), "r");
+  FILE* fout = open_memstream(&bp, &size);
+
   PyObject* pydata;
   if ((fin != NULL) && (fout != NULL))
   {
-     fputs(data, fin);
      fseek(fin, 0, SEEK_SET);
      /* Now do the usual qhull code (modified from qconvex.c). */
      qh_init_A(fin, fout, stderr, argc, argv);  /* sets qh qhull_command */
@@ -302,35 +262,17 @@ static PyObject* qvoronoi(PyObject *self, PyObject *args) {
          fprintf(stderr, "qhull internal warning (main): did not free %d bytes of long memory(%d pieces)\n",
             totlong, curlong);
      #endif
-
+     fclose(fin);
+     fclose(fout);
      /* We need to know the number of lines in the file to allocate the PyList
      object */
 
-     fseek(fout, 0, SEEK_SET);
-     int count = 0;
-     int MAX_BUF_SIZE = 300;
-     char buffer[MAX_BUF_SIZE];
-     while(fgets(buffer, MAX_BUF_SIZE, fout)){
-       count++;
-     }
-     fseek(fout, 0, SEEK_SET);
-     int i = 0;
-
-     pydata = PyList_New(count);
-     while(fgets(buffer,MAX_BUF_SIZE, fout)){
-        PyList_SetItem(pydata, i, PyString_FromString(buffer));
-        i++;
-     }
+     return Py_BuildValue("s", bp);
   }
   else
   {
      return NULL;
   }
-  fclose(fin);
-  fclose(fout);
-  remove(tmp_input_file);
-  remove(tmp_output_file);
-  return pydata;
 }
 
 
