@@ -10,17 +10,21 @@ __author__ = "Shyue Ping Ong"
 __version__ = "1.1"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyuep@gmail.com"
-__status__ = "Beta"
+__status__ = "Production"
 __date__ = "Nov 19 2012"
 
-
 from pyhull import qconvex
 from pyhull.simplex import Simplex
 
+
 class ConvexHull(object):
     """
     Convex hull for a set of points.
 
+    .. attribute: dim
+
+        Dimension of the points.
+
     .. attribute: points
 
         Original points supplied.
@@ -39,6 +43,10 @@ class ConvexHull(object):
                 [-0.5, 0.5], [0.5, -0.5], [0.5, 0.5]]
         """
         self.points = points
+        dim = map(len, self.points)
+        if max(dim) != min(dim):
+            raise ValueError("Input points must all have the same dimension!")
+        self.dim = dim[0]
         output = qconvex("i Qt", points)
         output.pop(0)
         self.vertices = [[int(i) for i in row.strip().split()]
